import sbt._

class CCToolcProject(info: ProjectInfo) extends DefaultProject(info) with FileTasks {
  val scalatest = "org.scalatest" % "scalatest" % "1.2"

  override def outputDirectoryName          = "bin"
  override def dependencyPath               = "lib"
  override def mainScalaSourcePath          = "src"
  override def testScalaSourcePath          = "test"
  override def shouldCheckOutputDirectories = false
  override def compileOptions               = super.compileOptions ++ Seq(Unchecked)

  override def cleanAction = super.cleanAction dependsOn(cleanScript)

  val scriptPath : Path = "." / "toolc"

  lazy val script = genScript
  def genScript = fileTask(scriptPath :: Nil)({
    log.info("Generating runner (sh) script")
    try {
      val nl = System.getProperty("line.separator")
      val f = scriptPath.asFile
      val fw = new java.io.FileWriter(f)
      fw.write("#!/bin/sh" + nl)
      fw.write("CLASSPATH=")
      fw.write(buildLibraryJar.absolutePath + ":")
      fw.write(dependencyPath.absolutePath + "/cafebabe.jar" + ":")
      fw.write(jarPath.absolutePath + nl)
      fw.write("java \\" + nl)
      val libStr = (buildLibraryJar.absolutePath).toString
      fw.write("    -Dscala.home=" + libStr.substring(0, libStr.length-21) + " \\" + nl)
      fw.write("    -classpath ${CLASSPATH} \\" + nl)
      fw.write("  toolc.Main $@" + nl)
//      fw.write("scala -cp ${CLASSPATH} tool.Main $@" + nl)
      fw.close
      f.setExecutable(true)
      None
    } catch {
      case e => Some("There was an error while generating the script file: " + e.getLocalizedMessage)
    }
  }) dependsOn(`package`) describedAs("Produce the runner (sh) script.")

  lazy val cleanScript = clnScript
  def clnScript = task {
    log.info("Deleting runner (sh) script")
    scriptPath.asFile.delete
    None
  }
}
